@@ -3,6 +3,7 @@ from ntpath import join
 from typing import List, Optional, Union, Tuple, Any
 
 import copy
+import math
 import pathlib
 import more_itertools
 import numpy as np
@@ -143,10 +144,10 @@ class Geometry:
             being holes or voids. The point can be located anywhere within the hole region.
             Only one point is required per hole region.
         :vartype holes: list[list[float, float]]
-        :cvar materials: Optional. A list of :class:`~sectionproperties.pre.pre.Material` objects that are to be
-            assigned, in order, to the regions defined by the given control_points. If not given, then
-            the :class:`~sectionproperties.pre.pre.DEFAULT_MATERIAL` will be used for each region.
-        :vartype materials: list[:class:`~sectionproperties.pre.pre.Material`]
+        :cvar material: Optional. A :class:`~sectionproperties.pre.pre.Material` object
+            that is to be assigned. If not given, then the
+            :class:`~sectionproperties.pre.pre.DEFAULT_MATERIAL` will be used.
+        :vartype materials: :class:`~sectionproperties.pre.pre.Material`
         """
         if len(control_points) != 1:
             raise ValueError(
@@ -224,7 +225,7 @@ class Geometry:
         :param filepath:
             File path to the rhino `.3dm` file.
         :type filepath: Union[str, pathlib.Path]
-        :param \**kwargs:
+        :param kwargs:
             See below.
         :raises RuntimeError:
             A RuntimeError is raised if two or more polygons are found.
@@ -289,7 +290,7 @@ class Geometry:
         :param r3dm_brep:
             A Rhino3dm.Brep encoded as a string.
         :type r3dm_brep: str
-        :param \**kwargs:
+        :param kwargs:
             See below.
         :return:
             A Geometry object found in the encoded string.
@@ -861,7 +862,12 @@ class Geometry:
         return new_geom
 
     def plot_geometry(
-        self, labels=["control_points"], title="Cross-Section Geometry", **kwargs
+        self,
+        labels=["control_points"],
+        title="Cross-Section Geometry",
+        cp=True,
+        legend=True,
+        **kwargs,
     ):
         """Plots the geometry defined by the input section.
 
@@ -870,7 +876,9 @@ class Geometry:
             to indicate no labels. Default is ["control_points"]
         :type labels: list[str]
         :param string title: Plot title
-        :param \**kwargs: Passed to :func:`~sectionproperties.post.post.plotting_context`
+        :param bool cp: If set to True, plots the control points
+        :param bool legend: If set to True, plots the legend
+        :param kwargs: Passed to :func:`~sectionproperties.post.post.plotting_context`
 
         :return: Matplotlib axes object
         :rtype: :class:`matplotlib.axes`
@@ -917,14 +925,15 @@ class Geometry:
 
                 ax.plot(h[0], h[1], "rx", markersize=5, markeredgewidth=1, label=label)
 
-            # plot the control points
-            for (i, cp) in enumerate(self.control_points):
-                if i == 0:
-                    label = "Control Points"
-                else:
-                    label = None
+            if cp:
+                # plot the control points
+                for (i, cp) in enumerate(self.control_points):
+                    if i == 0:
+                        label = "Control Points"
+                    else:
+                        label = None
 
-                ax.plot(cp[0], cp[1], "bo", markersize=5, label=label)
+                    ax.plot(cp[0], cp[1], "bo", markersize=5, label=label)
 
             # display the labels
             for label in labels:
@@ -953,7 +962,8 @@ class Geometry:
                         ax.annotate(str(i), xy=pt, color="r")
 
             # display the legend
-            ax.legend(loc="center left", bbox_to_anchor=(1, 0.5))
+            if legend:
+                ax.legend(loc="center left", bbox_to_anchor=(1, 0.5))
 
         return ax
 
@@ -1058,7 +1068,6 @@ class Geometry:
         """
         Perform difference on Geometry objects with the - operator
         """
-        material = pre.DEFAULT_MATERIAL
         if isinstance(self, CompoundGeometry):
             subs_geom_acc = []
             for geom in self.geoms:
@@ -1242,6 +1251,13 @@ class CompoundGeometry(Geometry):
             )
         if holes is None:
             holes = list()
+        if materials is not pre.DEFAULT_MATERIAL:
+            if len(materials) != len(control_points):
+                raise ValueError(
+                    f"If materials are provided, the number of materials in the list must "
+                    "match the number of control_points provided.\n"
+                    f"len(materials)=={len(materials)}, len(control_points)=={len(control_points)}."
+                )
 
         # First, generate all invidual polygons from points and facets
         current_polygon_points = []
@@ -1297,17 +1313,34 @@ class CompoundGeometry(Geometry):
                 f"does not match the number of control_points given ({len(control_points)})."
             )
         if not interiors:
-            return CompoundGeometry(
-                [
-                    Geometry(exterior, control_points=control_points[idx])
-                    for idx, exterior in enumerate(exteriors)
-                ]
-            )
+            if materials is pre.DEFAULT_MATERIAL:
+                return CompoundGeometry(
+                    [
+                        Geometry(
+                            exterior,
+                            control_points=control_points[idx],
+                            material=materials,
+                        )
+                        for idx, exterior in enumerate(exteriors)
+                    ]
+                )
+            else:
+                return CompoundGeometry(
+                    [
+                        Geometry(
+                            exterior,
+                            control_points=control_points[idx],
+                            material=materials[idx],
+                        )
+                        for idx, exterior in enumerate(exteriors)
+                    ]
+                )
+
         else:
             # "Punch" all holes through each exterior geometry
             punched_exteriors = []
             punched_exterior_geometries = []
-            for exterior in exteriors:
+            for idx, exterior in enumerate(exteriors):
                 punched_exterior = exterior
                 for interior in interiors:
                     punched_exterior = punched_exterior - interior
@@ -1322,12 +1355,25 @@ class CompoundGeometry(Geometry):
                             f"Control points given are not contained within the geometry"
                             f" once holes are subtracted: {control_points}"
                         )
-                exterior_geometry = Geometry(
-                    punched_exterior, control_points=exterior_control_point
-                )
-                punched_exterior_geometries.append(exterior_geometry)
+                if materials is pre.DEFAULT_MATERIAL:
 
-        return CompoundGeometry(punched_exterior_geometries)
+                    exterior_geometry = Geometry(
+                        punched_exterior,
+                        control_points=exterior_control_point,
+                        material=materials,
+                    )
+                    punched_exterior_geometries.append(exterior_geometry)
+
+                else:
+
+                    exterior_geometry = Geometry(
+                        punched_exterior,
+                        control_points=exterior_control_point,
+                        material=materials[idx],
+                    )
+                    punched_exterior_geometries.append(exterior_geometry)
+
+            return CompoundGeometry(punched_exterior_geometries)
 
     @classmethod
     def from_3dm(cls, filepath: Union[str, pathlib.Path], **kwargs) -> CompoundGeometry:
@@ -1336,7 +1382,7 @@ class CompoundGeometry(Geometry):
         :param filepath:
             File path to the rhino `.3dm` file.
         :type filepath: Union[str, pathlib.Path]
-        :param \**kwargs:
+        :param kwargs:
             See below.
         :return:
             A `CompoundGeometry` object.
@@ -1717,35 +1763,32 @@ class CompoundGeometry(Geometry):
                 self.facets.append([i_pnt_idx, j_pnt_idx])
 
             # add holes
+            existing_geom_holes = []
             for hole in geom.holes:
-                self.holes.append(tuple(hole))
+                existing_geom_holes.append(tuple(hole))
 
             # add control points
             for control_point in geom.control_points:
                 self.control_points.append(tuple(control_point))
 
-        # Check for holes created inadvertently from combined sections
-        inadvertent_holes = []
+        # Determine if new holes have been created or if existing
+        # holes have been destroyed (or "filled in").
+        resultant_holes = []
         unionized_poly = unary_union([geom.geom for geom in self.geoms])
         if isinstance(unionized_poly, MultiPolygon):
             for poly in unionized_poly.geoms:
                 for interior in poly.interiors:
-                    inadvertent_holes.append(
+                    resultant_holes.append(
                         tuple(Polygon(interior).representative_point().coords[0])
                     )
 
         elif isinstance(unionized_poly, Polygon):
             if Geometry(unionized_poly).holes:
-                inadvertent_holes += Geometry(unionized_poly).holes
+                resultant_holes = Geometry(unionized_poly).holes
             else:  # Holes have been destroyed through operations
-                inadvertent_holes = []
-                self.holes = []
+                resultant_holes = []
 
-        extra_holes = []
-        if set(inadvertent_holes) - set(self.holes):
-            extra_holes = [hole for hole in inadvertent_holes if hole not in self.holes]
-
-        self.holes += extra_holes
+        self.holes = resultant_holes
 
     def calculate_perimeter(self) -> float:
         """
@@ -1930,7 +1973,7 @@ def round_polygon_vertices(poly: Polygon, tol: int) -> Polygon:
     for interior in poly.interiors:
         rounded_interiors.append(np.round(interior.coords, tol))
     # print("Exterior: ", rounded_exterior)
-    # print("intterior: ", rounded_interiors)
+    # print("Interior: ", rounded_interiors)
     if not rounded_exterior.any():
         return Polygon()
     return Polygon(rounded_exterior, rounded_interiors)
@@ -1944,4 +1987,38 @@ def check_geometry_overlaps(lop: List[Polygon]) -> bool:
     """
     union_area = unary_union(lop).area
     sum_polygons = sum([poly.area for poly in lop])
-    return union_area != sum_polygons
+    return not math.isclose(union_area, sum_polygons)
+
+
+def check_geometry_disjoint(lop: List[Polygon]) -> bool:
+    """
+    Returns True if any polygons in 'lop' are disjoint. Returns
+    False, otherwise.
+    """
+    # Build polygon connectivity network
+    network = {}
+    for idx_i, poly1 in enumerate(lop):
+        for idx_j, poly2 in enumerate(lop):
+            if idx_i != idx_j:
+                connectivity = network.get(idx_i, set())
+                if poly1.intersection(poly2):
+                    connectivity.add(idx_j)
+                network[idx_i] = connectivity
+
+    def walk_network(node: int, network: dict, nodes_visited: list[int]) -> list[int]:
+        """
+        Walks the network modifying 'nodes_visited' as it walks.
+        """
+        connections = network.get(node, set())
+        for connection in connections:
+            if connection in nodes_visited:
+                continue
+            else:
+                nodes_visited.append(connection)
+                walk_network(connection, network, nodes_visited)
+        return nodes_visited
+
+    # Traverse polygon connectivity network
+    nodes_visited = [0]
+    walk_network(0, network, nodes_visited)
+    return set(nodes_visited) != set(network.keys())
